@@ -1,5 +1,4 @@
 package Module::Starter::Plugin::Template;
-# vi:et:sw=4 ts=4
 
 use warnings;
 use strict;
@@ -11,13 +10,11 @@ Module::Starter::Plugin::Template - module starter with templates
 
 =head1 VERSION
 
-Version 0.02
-
-    $Id: Template.pm 54 2007-02-06 22:04:46Z andy $
+Version 1.54_01
 
 =cut
 
-our $VERSION = '0.02';
+our $VERSION = '1.54_01';
 
 =head1 SYNOPSIS
 
@@ -123,8 +120,6 @@ sub module_guts {
 
     my $template = $self->{templates}{'Module.pm'};
     $self->render($template, \%options);
-
-    return;
 }
 
 =item Makefile_PL_guts
@@ -138,8 +133,19 @@ sub Makefile_PL_guts {
 
     my $template = $self->{templates}{'Makefile.PL'};
     $self->render($template, \%options);
+}
 
-    return;
+=item MI_Makefile_PL_guts
+
+=cut
+
+sub MI_Makefile_PL_guts {
+    my $self = shift;
+    my %options;
+    @options{qw(main_module main_pm_file)} = @_;
+
+    my $template = $self->{templates}{'MI_Makefile.PL'};
+    $self->render($template, \%options);
 }
 
 =item Build_PL_guts
@@ -153,8 +159,6 @@ sub Build_PL_guts {
 
     my $template = $self->{templates}{'Build.PL'};
     $self->render($template, \%options);
-
-    return;
 }
 
 =item Changes_guts
@@ -166,8 +170,6 @@ sub Changes_guts {
 
     my $template = $self->{templates}{'Changes'};
     $self->render($template);
-
-    return;
 }
 
 =item README_guts
@@ -181,8 +183,6 @@ sub README_guts {
 
     my $template = $self->{templates}{'README'};
     $self->render($template, \%options);
-
-    return;
 }
 
 =item t_guts
@@ -215,21 +215,17 @@ sub MANIFEST_guts {
 
     my $template = $self->{templates}{MANIFEST};
     $self->render($template, \%options);
-
-    return;
 }
 
-=item item cvsignore_guts
+=item item ignores_guts
 
 =cut
 
-sub cvsignore_guts {
+sub ignores_guts {
     my $self = shift;
 
-    my $template = $self->{templates}{cvsignore};
+    my $template = $self->{templates}{ignores};
     $self->render($template);
-
-    return;
 }
 
 =back
@@ -254,4 +250,6 @@ under the same terms as Perl itself.
 
 =cut
 
+# vi:et:sw=4 ts=4
+
 1;
